@@ -12,8 +12,6 @@ from imio.helpers.content import get_from_annotation
 from imio.helpers.content import get_object
 from imio.helpers.content import get_relations
 from imio.helpers.content import get_schema_fields
-from imio.helpers.content import get_state_infos
-from imio.helpers.content import get_transitions
 from imio.helpers.content import get_user_fullname
 from imio.helpers.content import get_vocab
 from imio.helpers.content import get_vocab_values
@@ -25,7 +23,6 @@ from imio.helpers.content import richtextval
 from imio.helpers.content import safe_delattr
 from imio.helpers.content import safe_encode
 from imio.helpers.content import set_to_annotation
-from imio.helpers.content import transitions
 from imio.helpers.content import uuidsToCatalogBrains
 from imio.helpers.content import uuidsToObjects
 from imio.helpers.content import uuidToCatalogBrain
@@ -79,18 +76,6 @@ class TestContentModule(IntegrationTestCase):
         self.assertEqual(obj, get_object(ptype='Document', oid='mydoc', title='My document', parent='folder'))
         self.assertEqual(obj, get_object(ptype='Document', oid='mydoc', title='My document', obj_path='folder/mydoc'))
 
-    def test_transitions(self):
-        obj = api.content.create(container=self.portal.folder, id='mydoc', type='Document')
-        self.assertEqual(api.content.get_state(obj), 'internal')
-        # apply one transition
-        transitions(obj, 'submit')
-        self.assertEqual(api.content.get_state(obj), 'pending')
-        # apply multiple transitions
-        transitions(obj, ['publish_internally', 'publish_externally'])
-        self.assertEqual(api.content.get_state(obj), 'external')
-        transitions(obj, ['submit', 'retract', 'hide'])
-        self.assertEqual(api.content.get_state(obj), 'private')
-
     def test_add_image(self):
         current_dir = os.path.dirname(os.path.abspath(__file__))
         obj = api.content.create(container=self.portal.folder, id='tt', type='testingtype')
@@ -306,6 +291,7 @@ class TestContentModule(IntegrationTestCase):
         folder_uid = self.portal.folder.UID()
         single_obj = uuidToObject(folder_uid)
         self.assertEqual(single_obj.UID(), folder_uid)
+        self.assertIsNone(uuidToObject('unknown_uid'))
 
     def test_disable_link_integrity_checks(self):
         self.assertTrue(self.portal.portal_properties.site_properties.enable_link_integrity_checks)
@@ -339,13 +325,6 @@ class TestContentModule(IntegrationTestCase):
         self.assertTrue(u"Folder" in values)
         self.assertTrue(u"Page" in values)
 
-    def test_get_state_infos(self):
-        self.portal.portal_workflow.setChainForPortalTypes(('Document', ), ('intranet_workflow', ))
-        obj = api.content.create(container=self.portal.folder, id='mydoc', title='My document', type='Document')
-        self.assertDictEqual(get_state_infos(obj), {'state_title': u'Internal draft', 'state_name': 'internal'})
-        transitions(obj, 'submit')
-        self.assertDictEqual(get_state_infos(obj), {'state_title': u'Pending review', 'state_name': 'pending'})
-
     def test_safe_delattr(self):
         attr_name = 'testing_attr_name'
         setattr(self.portal, attr_name, attr_name)
@@ -413,24 +392,19 @@ class TestContentModule(IntegrationTestCase):
 
     def test_user_fullname(self):
         self.assertIsNone(get_user_fullname(None))
+        self.assertEqual(get_user_fullname("", none_if_no_user=True), None)
         self.assertEqual(get_user_fullname(""), "")
+        self.assertEqual(get_user_fullname("unknown_user", none_if_no_user=True), None)
         self.assertEqual(get_user_fullname("unknown_user"), "unknown_user")
         # create some users
         user1 = api.user.create('a@b.be', 'user1', '12345', properties={'fullname': 'Stéphan Smith'})
         api.user.create('a@b.be', 'user2', '12345', properties={'fullname': ''})
-        self.assertEqual(get_user_fullname("user1"), 'Stéphan Smith')
-        self.assertEqual(user1.getProperty("fullname"), get_user_fullname("user1"))
-        self.assertEqual(get_user_fullname("user2"), 'user2')
-
-    def test_get_transitions(self):
-        obj = api.content.create(container=self.portal.folder, id='mydoc', type='Document')
-        self.assertEqual(get_transitions(obj),
-                         ['publish_internally', 'hide', 'submit'])
-        transitions(obj, 'submit')
-        self.assertEqual(get_transitions(obj),
-                         ['publish_internally', 'retract', 'publish_externally', 'reject'])
-        transitions(obj, 'publish_externally')
-        self.assertEqual(get_transitions(obj), ['retract'])
+        self.assertEqual(get_user_fullname("user1"), u'Stéphan Smith')
+        self.assertEqual(user1.getProperty("fullname").decode('utf8'), get_user_fullname("user1"))
+        self.assertEqual(get_user_fullname("user2"), u'user2')
+        # group
+        self.assertEqual(get_user_fullname("Reviewers", none_if_no_user=True), None)
+        self.assertEqual(get_user_fullname("Reviewers"), u'Reviewers')
 
     def test_base_getattr(self):
         obj = api.content.create(container=self.portal.folder, id='mydoc', type='Document')
